@@ -89,11 +89,10 @@ class Connection(object):
             self.poller = poller.Poller()
             self.is_running = True
             self.thread = threading.Thread(target=self.run)
-            self.thread.setDaemon(True)
+            self.thread.daemon = True
             self.thread.start()
 
     def run(self):
-        errors = 0
         while self.is_running:
             # If we fail in an Idl call, we could have missed an update
             # from the server, leaving us out of sync with ovsdb-server.
@@ -108,22 +107,10 @@ class Connection(object):
                     self.idl.run()
             except Exception as e:
                 # This shouldn't happen, but is possible if there is a bug
-                # in python-ovs
-                errors += 1
+                # in python-ovs, or an unhandled exception in overridden
+                # Idl.notify() code
                 LOG.exception(e)
-                with self.lock:
-                    self.idl.force_reconnect()
-                    try:
-                        idlutils.wait_for_change(self.idl, self.timeout)
-                    except Exception as e:
-                        # This could throw the same exception as idl.run()
-                        # or Exception("timeout"), either way continue
-                        LOG.exception(e)
-                sleep = min(2 ** errors, 60)
-                LOG.info("Trying to recover, sleeping %s seconds", sleep)
-                time.sleep(sleep)
                 continue
-            errors = 0
             txn = self.txns.get_nowait()
             if txn is not None:
                 try:
@@ -212,13 +199,29 @@ class OvsdbIdl(idl.Idl):
 
         schema = schema_helper.get_idl_schema()
         self._db = schema
-        self.tables = schema.tables
-        for table in schema.tables.values():
+        removed = self.tables.keys() - schema.tables.keys()
+        added = schema.tables.keys() - self.tables.keys()
+
+        # stop monitoring removed tables
+        for table in removed:
+            self.cond_change(table, [False])
+            del self.tables[table]
+
+        try:
+            _tables = idl.IdlTable.schema_tables(self, schema)
+        except AttributeError:
+            _tables = None
+        # add new tables as Idl.__init__ does
+        for table in (schema.tables[table] for table in added):
+            self.tables[table.name] = _tables[table.name] if _tables else table
             for column in table.columns.values():
                 if not hasattr(column, 'alert'):
                     column.alert = True
             table.need_table = False
             table.rows = custom_index.IndexedRows(table)
             table.idl = self
-            table.condition = [True]
+            try:
+                table.condition = idl.ConditionState()
+            except AttributeError:
+                table.condition = [True]
             table.cond_changed = False
